pub struct Input {Show 13 fields
pub url: Option<FHIRUri>,
pub context: Option<FHIRUri>,
pub valueSet: Option<ValueSet>,
pub valueSetVersion: Option<FHIRString>,
pub code: Option<FHIRCode>,
pub system: Option<FHIRUri>,
pub systemVersion: Option<FHIRString>,
pub display: Option<FHIRString>,
pub coding: Option<Coding>,
pub codeableConcept: Option<CodeableConcept>,
pub date: Option<FHIRDateTime>,
pub abstract_: Option<FHIRBoolean>,
pub displayLanguage: Option<FHIRCode>,
}Fields
url: Option<FHIRUri>Value set Canonical URL. The server must know the value set (e.g. it is defined explicitly in the server’s value sets, or it is defined implicitly by some code system known to the server
context: Option<FHIRUri>The context of the value set, so that the server can resolve this to a value set to validate against. The recommended format for this URI is [Structure Definition URL]#[name or path into structure definition] e.g. http://hl7.org/fhir/StructureDefinition/observation-hspc-height-hspcheight#Observation.interpretation. Other forms may be used but are not defined. This form is only usable if the terminology server also has access to the conformance registry that the server is using, but can be used to delegate the mapping from an application context to a binding at run-time
valueSet: Option<ValueSet>The value set is provided directly as part of the request. Servers may choose not to accept value sets in this fashion. This parameter is used when the client wants the server to expand a value set that is not stored on the server
valueSetVersion: Option<FHIRString>The identifier that is used to identify a specific version of the value set to be used when validating the code. This is an arbitrary value managed by the value set author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available.
code: Option<FHIRCode>The code that is to be validated. If a code is provided, a system or a context must be provided (if a context is provided, then the server SHALL ensure that the code is not ambiguous without a system)
system: Option<FHIRUri>The system for the code that is to be validated
systemVersion: Option<FHIRString>The version of the system, if one was provided in the source data
display: Option<FHIRString>The display associated with the code, if provided. If a display is provided a code must be provided. If no display is provided, the server cannot validate the display value, but may choose to return a recommended display name using the display parameter in the outcome. Whether displays are case sensitive is code system dependent
coding: Option<Coding>A coding to validate
codeableConcept: Option<CodeableConcept>A full codeableConcept to validate. The server returns true if one of the coding values is in the value set, and may also validate that the codings are not in conflict with each other if more than one is present
date: Option<FHIRDateTime>The date for which the validation should be checked. Normally, this is the current conditions (which is the default values) but under some circumstances, systems need to validate that a correct code was used at some point in the past. A typical example of this would be where code selection is constrained to the set of codes that were available when the patient was treated, not when the record is being edited. Note that which date is appropriate is a matter for implementation policy.
abstract_: Option<FHIRBoolean>If this parameter has a value of true, the client is stating that the validation is being performed in a context where a concept designated as ‘abstract’ is appropriate/allowed to be used, and the server should regard abstract codes as valid. If this parameter is false, abstract codes are not considered to be valid.
Note that. ‘abstract’ is a property defined by many HL7 code systems that indicates that the concept is a logical grouping concept that is not intended to be used asa ‘concrete’ concept to in an actual patient/care/process record. This language is borrowed from Object Orienated theory where ‘asbtract’ objects are never instantiated. However in the general record and terminology eco-system, there are many contexts where it is appropraite to use these codes e.g. as decision making criterion, or when editing value sets themselves. This parameter allows a client to indicate to the server that it is working in such a context.
displayLanguage: Option<FHIRCode>Specifies the language to be used for description when validating the display property